@@ -15,7 +15,7 @@ tx_params = {
     "gasPrice": "200000000000",
 }
 cactus_extra_params = {
-    "chainId": 42,  # Kovan
+    "chainId": 5,  # Görli
     "note": "Some information"
 }
 
@@ -26,7 +26,7 @@ print(type(transaction))
 # <class 'mmisdk.common.transaction.Transaction'>
 
 print(transaction)
-# id='JTQMNHSSTID888888000792'
+# id='5CM05NCLMRD888888000800'
 # type='1'
 # from_='0xFA42B2eCf59abD6d6BD4BF07021D870E2FC0eF20'
 # to=None
