@@ -8,10 +8,10 @@ custodian = factory.create_for("qredo-dev", "YOUR-REFRESH-TOKEN-QREDO-DEV")
 
 # Build tx details
 tx_params = {
-    "from": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
+    "from_": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
     "to": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
-    "value": "1",
-    "gasLimit": "21000",
+    "value": "100000000000000000",  # in Wei
+    "gas": "21000",
     "gasPrice": "1000",
     # "data": "0xsomething",
     # "type": "2"
@@ -19,8 +19,7 @@ tx_params = {
     # "maxFeePerGas": "12321321",
 }
 qredo_extra_params = {
-    "chainId": 1,
-    "note": "test"
+    "chainID": 1,
 }
 
 # Create the tx from details and send it to the custodian
@@ -33,7 +32,7 @@ print(transaction)
 # type='1'
 # from_='0x62468FD916bF27A3b76d3de2e5280e53078e13E1'
 # to='0x62468FD916bF27A3b76d3de2e5280e53078e13E1'
-# value='1'
+# value='100000000000000000'
 # gas='21000'
 # gasPrice='1000'
 # maxPriorityFeePerGas=None
