@@ -13,13 +13,12 @@ class TransactionStatus(BaseModel):
 
 
 class Transaction(BaseModel):
-    """Common data format returned by all custodian clients."""
     id: str
     type: str
     from_: str
     to: Optional[str]
-    value: Optional[str]
-    gas: str
+    value: Optional[str]  # In Wei
+    gas: str  # Same as gasLimit
     gasPrice: Optional[str]
     maxPriorityFeePerGas: Optional[str]
     maxFeePerGas: Optional[str]
