@@ -8,8 +8,7 @@ class BaseTxParams(BaseModel):
     to: str
     value: Optional[str]
     data: Optional[str]
-    gasLimit: str
-    gas: Optional[str]
+    gas: Optional[str]  # Same as gasLimit
     nonce: Optional[str]
 
 
@@ -18,7 +17,7 @@ class LegacyTxParams(BaseTxParams):
     gasPrice: str
 
 
-class EIP11559TxParams(BaseTxParams):
+class EIP1559TxParams(BaseTxParams):
     type = 2
     maxPriorityFeePerGas: str
     maxFeePerGas: str
